@@ -224,8 +224,8 @@ def convert_binary_file(input_file, output_file='binconv.txt'):
         opath.parent.mkdir(parents=True)
 
     status = 1
-    with open(str(opath.absolute()),'w') as ofile:
-        with open(str(ipath.absolute()),'rb') as ifile:
+    with open(str(opath.absolute()), 'w') as ofile:
+        with open(str(ipath.absolute()), 'rb') as ifile:
             bord = None
             bform = None
             npoints = 0
@@ -251,9 +251,9 @@ def convert_binary_file(input_file, output_file='binconv.txt'):
                             fsize = struct.calcsize(bord+bform)
                             bdata = ifile.read(npoints*fsize)
                             nstr = "%d" % (npoints)
-                            vals = struct.unpack(bord+nstr+bform,bdata)
-                            for ii in np.arange(0,len(vals)):
-                                if re.match(r'^[fd]$',bform,flags=re.IGNORECASE):
+                            vals = struct.unpack(bord+nstr+bform, bdata)
+                            for ii in range(len(vals)):
+                                if re.match(r'^[fd]$', bform, flags=re.IGNORECASE):
 #                                    ofile.write("%20.10e" % (scale * vals[ii]))
                                     ofile.write("%20.10e" % (vals[ii]))
                                 else:
@@ -339,7 +339,7 @@ def read_binary_file(input_path, output_file=None):
         raise Exception("Extention of file %s not in allowed list. Abort." % (str(ipath.absolute())))
 
     if isinstance(output_file,str):
-        convert_binary_file(str(ipath.absolute()),output_file)
+        convert_binary_file(str(ipath.absolute()), output_file)
 
     # Store data from input file in dictionary
     data = collections.OrderedDict()
@@ -455,7 +455,7 @@ def standardize_data_representation(data, header_info, endianness):
     return data
 
 
-def write_as_EX2GK_output(data,varlist=None,output_file='custom.txt',timeslice=None,timeout=None):
+def write_as_EX2GK_output(data, varlist=None, output_file='custom.txt', timeslice=None, timeout=None):
     """
     Writes JETTO binary data, read using the function
     found within these tools, in the standardized ASCII
@@ -463,7 +463,7 @@ def write_as_EX2GK_output(data,varlist=None,output_file='custom.txt',timeslice=N
     between fitted and simulated profiles. Recommended
     to use .txt extension, but not necessary.
     """
-    if not isinstance(data,(dict,collections.OrderedDict)):
+    if not isinstance(data, (dict, collections.OrderedDict)):
         raise TypeError("Invalid input data structure, must be a dictionary. Abort.")
     elif "INFO" not in data:
         raise TypeError("Input data dictionary not correctly formatted. Abort.")
@@ -473,28 +473,28 @@ def write_as_EX2GK_output(data,varlist=None,output_file='custom.txt',timeslice=N
     ofname = 'custom.txt'
     tsi = -1
     time = None
-    if isinstance(varlist,(list,tuple)):
-        for qi in np.arange(0,len(varlist)):
+    if isinstance(varlist, (list, tuple)):
+        for qi in range(len(varlist)):
             if varlist[qi] in data:
                 qlist.append(varlist[qi])
-    if isinstance(output_file,str):
+    if isinstance(output_file, str):
         ofname = output_file
     opath = Path(ofname)
     if not opath.parent.exists():
         opath.parent.mkdir(parents=True)
-    if isinstance(timeslice,(int,float,np.float16,np.float32,np.float64)) and "TIME" in data:
+    if isinstance(timeslice, (int, float, np.float16, np.float32, np.float64)) and "TIME" in data:
         tvec = data["TIME"].flatten()
         idxv = np.where(tvec >= float(timeslice))[0]
         if len(idxv) > 0:
             tsi = idxv[0] if np.abs(tvec[idxv[0]] - float(timeslice)) <= np.abs(tvec[idxv[0] - 1] - float(timeslice)) else idxv[0] - 1
-    if isinstance(timeout,(int,float,np.float16,np.float32,np.float64)):
+    if isinstance(timeout, (int, float, np.float16, np.float32, np.float64)):
         time = float(timeout)
     if time is None and "TIME" in data:
         tvec = data["TIME"].flatten()
         time = float(tvec[tsi])
 
     if len(qlist) > 0:
-        with open(str(opath.absolute()),'w') as ofile:
+        with open(str(opath.absolute()), 'w') as ofile:
             if data:
                 ofile.write("### EX2GK - JSP Data Conversion File ###\n")
                 ofile.write("\n")
@@ -506,19 +506,19 @@ def write_as_EX2GK_output(data,varlist=None,output_file='custom.txt',timeslice=N
                 ofile.write("\n")
                 ofile.write("END OF HEADER\n")
                 ofile.write("\n")
-            for jj in np.arange(0,len(qlist)):
+            for jj in range(len(qlist)):
                 xbase = data["INFO"][qlist[jj]]["XBASE"]
-                xfit = data[xbase][tsi,:].flatten()
-                yfit = data[qlist[jj]][tsi,:].flatten()
+                xfit = data[xbase][tsi, :].flatten()
+                yfit = data[qlist[jj]][tsi, :].flatten()
                 yefit = np.zeros(xfit.shape)
                 qtag = conv[qlist[jj]] if qlist[jj] in conv else qlist[jj]
-                ofile.write("%15s%20s%20s\n" % ("RHOTORN",qtag+" Sim","Err. "+qtag+" Sim"))
-                for ii in np.arange(0,xfit.size):
-                    ofile.write("%15.4f%20.6e%20.6e\n" % (xfit[ii],yfit[ii],yefit[ii]))
+                ofile.write("%15s%20s%20s\n" % ("RHOTORN", qtag+" Sim", "Err. "+qtag+" Sim"))
+                for ii in range(xfit.size):
+                    ofile.write("%15.4f%20.6e%20.6e\n" % (xfit[ii], yfit[ii], yefit[ii]))
                 ofile.write("\n")
 
 
-def create_exfile_structure(database,shot,version_tag=None,extfile=False):
+def create_exfile_structure(database, shot, version_tag=None, extfile=False):
     """
     Creates an empty structure for JETTO binary ex-file
     representation in memory. The structure is only useful
@@ -575,14 +575,14 @@ def create_exfile_structure(database,shot,version_tag=None,extfile=False):
     return data
 
 
-def write_binary_exfile(data,output_file='custom'):
+def write_binary_exfile(data, output_file='custom'):
     """
     Writes a customized JETTO binary ex-file, for use
     within JETTO. Recommended to read in a similar ex-file
     to acquire the necessary data structure used by this
     tool. Only writes .ex and .ext files.
     """
-    if not isinstance(data,(dict,collections.OrderedDict)):
+    if not isinstance(data, (dict, collections.OrderedDict)):
         raise TypeError("Invalid input data structure, must be a dictionary. Abort.")
     elif "INFO" not in data or "SECTIONS" not in data:
         raise TypeError("Input data dictionary not correctly formatted. Abort.")
@@ -593,7 +593,7 @@ def write_binary_exfile(data,output_file='custom'):
     ds = data["SECTIONS"]
     baseidx = ds.index('PPF Base Vectors') if 'PPF Base Vectors' in ds else 3
     ofname = 'custom.ex'
-    if isinstance(output_file,str):
+    if isinstance(output_file, str):
         ofname = output_file
     if 'Profiles' in ds and not ofname.endswith('.ex'):
         ofname = ofname + '.ex'
@@ -605,11 +605,11 @@ def write_binary_exfile(data,output_file='custom'):
 
     status = 1
     bord = byte_ordering[data["FILE FORMAT"]] if "FILE FORMAT" in data else byte_ordering['b']
-    with open(str(opath.absolute()),'wb') as ofile:
+    with open(str(opath.absolute()), 'wb') as ofile:
         NL = '\n'.encode()
-        for ii in np.arange(1,len(ds) + 1):
+        for ii in range(1, len(ds) + 1):
 
-            if not re.match('^Profiles$',ds[ii-1],flags=re.IGNORECASE):
+            if not re.match('^Profiles$', ds[ii-1], flags=re.IGNORECASE):
                 hstr1 = '*'
                 ofile.write(hstr1.encode() + NL)
                 hstr2 = '*' + ds[ii-1]
@@ -618,7 +618,7 @@ def write_binary_exfile(data,output_file='custom'):
                     if "SECNUM" in di[key] and di[key]["SECNUM"] == ii:
                         nstr = '1'
                         rnum = 0
-                        if not re.match(r'^char$',di[key]["FORM"],flags=re.IGNORECASE):
+                        if not re.match(r'^char$', di[key]["FORM"], flags=re.IGNORECASE):
                             nstr = "%d" % (data[key].shape[1])
                             rnum = -1
                         if "SEQ" in di[key]:
@@ -637,33 +637,33 @@ def write_binary_exfile(data,output_file='custom'):
                             rnum = 2
                         elif "UNITS" in di[key]:
                             rnum = 1
-                        rstr = '%d' % (rnum) if rnum >= 0 and not re.match(r'^Shot$',key,flags=re.IGNORECASE) else '0'
+                        rstr = '%d' % (rnum) if rnum >= 0 and not re.match(r'^Shot$', key, flags=re.IGNORECASE) else '0'
                         hdelim = ';'
-                        fstr = '#' + hdelim.join((di[key]["FORM"],'1',nstr,di[key]["LABEL"],rstr))
+                        fstr = '#' + hdelim.join((di[key]["FORM"], '1', nstr, di[key]["LABEL"], rstr))
                         ofile.write(fstr.encode() + NL)
                         if rnum >= 1:
-                            estr = di[key]["UNITS"] if isinstance(di[key]["UNITS"],str) else ''
+                            estr = di[key]["UNITS"] if isinstance(di[key]["UNITS"], str) else ''
                             ofile.write(estr.encode() + NL)
                         if rnum >= 2:
-                            estr = di[key]["DESC"] if isinstance(di[key]["DESC"],str) else ''
+                            estr = di[key]["DESC"] if isinstance(di[key]["DESC"], str) else ''
                             ofile.write(estr.encode() + NL)
                         if rnum >= 3:
-                            estr = di[key]["SCSTR"] if isinstance(di[key]["SCSTR"],str) else ''
+                            estr = di[key]["SCSTR"] if isinstance(di[key]["SCSTR"], str) else ''
                             ofile.write(estr.encode() + NL)
                         if rnum >= 4:
-                            estr = di[key]["XBASE"] if isinstance(di[key]["XBASE"],str) else ''
+                            estr = di[key]["XBASE"] if isinstance(di[key]["XBASE"], str) else ''
                             ofile.write(estr.encode() + NL)
                         if rnum >= 5:
-                            estr = di[key]["UID"] if isinstance(di[key]["UID"],str) else ''
+                            estr = di[key]["UID"] if isinstance(di[key]["UID"], str) else ''
                             ofile.write(estr.encode() + NL)
                         if rnum >= 6:
-                            estr = di[key]["DDA"] if isinstance(di[key]["DDA"],str) else ''
+                            estr = di[key]["DDA"] if isinstance(di[key]["DDA"], str) else ''
                             ofile.write(estr.encode() + NL)
                         if rnum >= 7:
-                            estr = di[key]["DTYPE"] if isinstance(di[key]["DTYPE"],str) else ''
+                            estr = di[key]["DTYPE"] if isinstance(di[key]["DTYPE"], str) else ''
                             ofile.write(estr.encode() + NL)
                         if rnum >= 8:
-                            estr = di[key]["SEQ"] if isinstance(di[key]["SEQ"],str) else ''
+                            estr = di[key]["SEQ"] if isinstance(di[key]["SEQ"], str) else ''
                             ofile.write(estr.encode() + NL)
                         if rnum == 0:
                             ofile.write(data[key].encode() + NL)
@@ -671,17 +671,17 @@ def write_binary_exfile(data,output_file='custom'):
                             scale = di[key]["SCALE"] if "SCALE" in di[key] else 1.0
                             dtype = dtypes[di[key]["FORM"]]
                             dsize = dsizes[di[key]["FORM"]]
-                            for jj in np.arange(0,data[key].shape[1]):
+                            for jj in range(data[key].shape[1]):
                                 dstr = b''
-                                if re.match(r'^[fd]$',dtype,flags=re.IGNORECASE):
-                                    dstr = struct.pack(bord+dtype,float(data[key][0,jj] / scale))
+                                if re.match(r'^[fd]$', dtype, flags=re.IGNORECASE):
+                                    dstr = struct.pack(bord+dtype, float(data[key][0, jj] / scale))
                                 else:
-                                    dstr = struct.pack(bord+dtype,int(data[key][0,jj] / scale))
+                                    dstr = struct.pack(bord+dtype, int(data[key][0, jj] / scale))
                                 ofile.write(dstr)
                             ofile.write(NL)
 
-            elif "TVEC1" in data and isinstance(data["TVEC1"],np.ndarray):
-                for tt in np.arange(0,data["TVEC1"].shape[0]):
+            elif "TVEC1" in data and isinstance(data["TVEC1"], np.ndarray):
+                for tt in range(data["TVEC1"].shape[0]):
                     hstr1 = '*'
                     ofile.write(hstr1.encode() + NL)
                     hstr2 = '*' + ds[ii-1]
@@ -690,7 +690,7 @@ def write_binary_exfile(data,output_file='custom'):
                         if "SECNUM" in di[key] and di[key]["SECNUM"] == ii:
                             nstr = '1'
                             rnum = 0
-                            if not re.match(r'^char$',di[key]["FORM"],flags=re.IGNORECASE):
+                            if not re.match(r'^char$', di[key]["FORM"], flags=re.IGNORECASE):
                                 nstr = "%d" % (data[key].shape[1])
                                 rnum = -1
                             if "SEQ" in di[key]:
@@ -711,31 +711,31 @@ def write_binary_exfile(data,output_file='custom'):
                                 rnum = 1
                             rstr = '%d' % (rnum) if rnum >= 0 else '0'
                             hdelim = ';'
-                            fstr = '#' + hdelim.join((di[key]["FORM"],'1',nstr,di[key]["LABEL"],rstr))
+                            fstr = '#' + hdelim.join((di[key]["FORM"], '1', nstr, di[key]["LABEL"], rstr))
                             ofile.write(fstr.encode() + NL)
                             if rnum >= 1:
-                                estr = di[key]["UNITS"] if isinstance(di[key]["UNITS"],str) else ''
+                                estr = di[key]["UNITS"] if isinstance(di[key]["UNITS"], str) else ''
                                 ofile.write(estr.encode() + NL)
                             if rnum >= 2:
-                                estr = di[key]["DESC"] if isinstance(di[key]["DESC"],str) else ''
+                                estr = di[key]["DESC"] if isinstance(di[key]["DESC"], str) else ''
                                 ofile.write(estr.encode() + NL)
                             if rnum >= 3:
-                                estr = di[key]["SCSTR"] if isinstance(di[key]["SCSTR"],str) else ''
+                                estr = di[key]["SCSTR"] if isinstance(di[key]["SCSTR"], str) else ''
                                 ofile.write(estr.encode() + NL)
                             if rnum >= 4:
-                                estr = di[key]["XBASE"] if isinstance(di[key]["XBASE"],str) else ''
+                                estr = di[key]["XBASE"] if isinstance(di[key]["XBASE"], str) else ''
                                 ofile.write(estr.encode() + NL)
                             if rnum >= 5:
-                                estr = di[key]["UID"] if isinstance(di[key]["UID"],str) else ''
+                                estr = di[key]["UID"] if isinstance(di[key]["UID"], str) else ''
                                 ofile.write(estr.encode() + NL)
                             if rnum >= 6:
-                                estr = di[key]["DDA"] if isinstance(di[key]["DDA"],str) else ''
+                                estr = di[key]["DDA"] if isinstance(di[key]["DDA"], str) else ''
                                 ofile.write(estr.encode() + NL)
                             if rnum >= 7:
-                                estr = di[key]["DTYPE"] if isinstance(di[key]["DTYPE"],str) else ''
+                                estr = di[key]["DTYPE"] if isinstance(di[key]["DTYPE"], str) else ''
                                 ofile.write(estr.encode() + NL)
                             if rnum >= 8:
-                                estr = di[key]["SEQ"] if isinstance(di[key]["SEQ"],str) else ''
+                                estr = di[key]["SEQ"] if isinstance(di[key]["SEQ"], str) else ''
                                 ofile.write(estr.encode() + NL)
                             if rnum == 0:
                                 ofile.write(data[key].encode() + NL)
@@ -743,19 +743,19 @@ def write_binary_exfile(data,output_file='custom'):
                                 scale = di[key]["SCALE"] if "SCALE" in di[key] else 1.0
                                 dtype = dtypes[di[key]["FORM"]]
                                 dsize = dsizes[di[key]["FORM"]]
-                                for jj in np.arange(0,data[key].shape[1]):
+                                for jj in range(data[key].shape[1]):
                                     dstr = b''
-                                    if re.match(r'^[fd]$',dtype,flags=re.IGNORECASE):
+                                    if re.match(r'^[fd]$', dtype, flags=re.IGNORECASE):
                                         if data[key].shape[0] > tt:
-                                            dstr = struct.pack(bord+dtype,float(data[key][tt,jj] / scale))
+                                            dstr = struct.pack(bord+dtype, float(data[key][tt, jj] / scale))
                                         else:
-                                            dstr = struct.pack(bord+dtype,float(data[key][-1,jj] / scale))
+                                            dstr = struct.pack(bord+dtype, float(data[key][-1, jj] / scale))
                                             print("   Less time slices than expected in field: %10s" % (di[key]["LABEL"]))
                                     else:
                                         if data[key].shape[0] > tt:
-                                            dstr = struct.pack(bord+dtype,int(data[key][tt,jj] / scale))
+                                            dstr = struct.pack(bord+dtype, int(data[key][tt, jj] / scale))
                                         else:
-                                            dstr = struct.pack(bord+dtype,int(data[key][-1,jj] / scale))
+                                            dstr = struct.pack(bord+dtype, int(data[key][-1, jj] / scale))
                                             print("   Less time slices than expected in field: %10s" % (di[key]["LABEL"]))
                                     ofile.write(dstr)
                                 ofile.write(NL)
@@ -770,7 +770,7 @@ def write_binary_exfile(data,output_file='custom'):
     return status
 
 
-def add_entry(data,key,moddata,dtype,units,description,scale,xbase,tag=None):
+def add_entry(data, key, moddata, dtype, units, description, scale, xbase, tag=None):
     """
     Use this function to add fields to the Python data structure
     generated by this tool. Providence must be explicitly
@@ -780,21 +780,21 @@ def add_entry(data,key,moddata,dtype,units,description,scale,xbase,tag=None):
     idata = None
     ibase = None
     itag = 'Python Addition Tool'
-    if isinstance(key,str):
+    if isinstance(key, str):
         ikey = key
-    if isinstance(moddata,(list,tuple,np.ndarray)):
+    if isinstance(moddata, (list, tuple, np.ndarray)):
         idata = np.atleast_2d(moddata)
-    if isinstance(xbase,str):
+    if isinstance(xbase, str):
         ibase = xbase
-    if isinstance(tag,str):
+    if isinstance(tag, str):
         itag = itag + ' - ' + tag
 
     odata = copy.deepcopy(data)
-    if isinstance(data,(dict,collections.OrderedDict)) and ikey is not None:
+    if isinstance(data, (dict, collections.OrderedDict)) and ikey is not None:
         check_flag = True
         if ikey not in ["TVEC1", "XVEC1"]:
             check_array = [False] * idata.ndim
-            for ii in range(0,len(check_array)):
+            for ii in range(len(check_array)):
                 if "TVEC1" in data and idata.shape[ii] == data["TVEC1"].size:
                     check_array[ii] = True
                 if "XVEC1" in data and idata.shape[ii] == data["XVEC1"].size:
@@ -837,7 +837,7 @@ def add_entry(data,key,moddata,dtype,units,description,scale,xbase,tag=None):
     return odata
 
 
-def modify_entry(data,key,moddata,tag=None):
+def modify_entry(data, key, moddata, tag=None):
     """
     Use this function to modify the Python data structure
     generated by this tool, in order to prepare it for
@@ -848,19 +848,19 @@ def modify_entry(data,key,moddata,tag=None):
     ikey = None
     idata = None
     itag = 'Python Modification Tool'
-    if isinstance(key,str):
+    if isinstance(key, str):
         ikey = key
-    if isinstance(moddata,(list,tuple)):
+    if isinstance(moddata, (list, tuple)):
         idata = np.array(moddata)
-    elif isinstance(moddata,np.ndarray):
+    elif isinstance(moddata, np.ndarray):
         idata = moddata.copy()
-    if isinstance(tag,str):
+    if isinstance(tag, str):
         itag = itag + ' - ' + tag
 
     odata = None
-    if isinstance(data,(dict,collections.OrderedDict)) and ikey in data:
+    if isinstance(data, (dict, collections.OrderedDict)) and ikey in data:
         if data[ikey].size == idata.size:
-            idata = np.reshape(idata,data[ikey].shape)
+            idata = np.reshape(idata, data[ikey].shape)
         if data[ikey].shape == idata.shape:
             uname = getuser()
             odata = copy.deepcopy(data)
@@ -871,7 +871,7 @@ def modify_entry(data,key,moddata,tag=None):
             odata["INFO"][ikey]["SEQ"] = '0'      # Sequence number in PPF system (replaced with zero string)
         else:
             print("   Input data is not the same shape as existing data structure: ", data[ikey].shape)
-    elif isinstance(data,(dict,collections.OrderedDict)):
+    elif isinstance(data, (dict, collections.OrderedDict)):
         print("   Base data to be modified does not contain the entry %s. Modification aborted.")
     else:
         print("   Base data to be modified is not a dictionary. Use read_binary_file() function to create it.")
@@ -879,7 +879,7 @@ def modify_entry(data,key,moddata,tag=None):
     return odata
 
 
-def modify_exfile(inputdata=None,qlist=None,exfilename=None,outfile=None,globaltag=None):
+def modify_exfile(inputdata=None, qlist=None, exfilename=None, outfile=None, globaltag=None):
     """
     Use this function to modify the Python data structure
     generated by this tools via an input dictionary
@@ -892,23 +892,23 @@ def modify_exfile(inputdata=None,qlist=None,exfilename=None,outfile=None,globalt
     gtag = None
     expath = None
     opath = Path('./modded_exfile.txt')
-    if isinstance(inputdata,(dict,collections.OrderedDict)):
+    if isinstance(inputdata, (dict, collections.OrderedDict)):
         pdata = copy.deepcopy(inputdata)
-    if isinstance(qlist,(list,tuple)) and len(qlist) > 0:
+    if isinstance(qlist, (list, tuple)) and len(qlist) > 0:
         qqlist = []
         for item in qlist:
-            if isinstance(pdata,(dict,collections.OrderedDict)) and item in pdata:
+            if isinstance(pdata, (dict, collections.OrderedDict)) and item in pdata:
                 qqlist.append(item)
-    if isinstance(exfilename,str):
+    if isinstance(exfilename, str):
         exname = exfilename
         if not exname.endswith('.ex'):
             exname = exname + '.ex'
         expath = Path(exname)
-    if isinstance(outfile,str):
+    if isinstance(outfile, str):
         opath = Path(outfile)
     if not opath.parent.exists():
         opath.parent.mkdir(parents=True)
-    if isinstance(globaltag,str):
+    if isinstance(globaltag, str):
         gtag = globaltag
 
     status = 1
@@ -918,13 +918,13 @@ def modify_exfile(inputdata=None,qlist=None,exfilename=None,outfile=None,globalt
             fmodified = False
             for qq in qqlist:
                 if qq in exdata:
-                    exdata = modify_entry(exdata,qq,pdata[qq].flatten(),tag=gtag)
+                    exdata = modify_entry(exdata, qq, pdata[qq].flatten(), tag=gtag)
                     fmodified = True
                 else:
-                    print("Quantity %s not found in ex-file, %s. Quantity not changed." % (qq,exname))
+                    print("Quantity %s not found in ex-file, %s. Quantity not changed." % (qq, exname))
             if fmodified:
                 exfile = opath.parent / (str(opath.stem) + '.ex')
-                status = write_binary_exfile(exdata,str(exfile.absolute()))
+                status = write_binary_exfile(exdata, str(exfile.absolute()))
                 if status != 0:
                     print("Error occurred while writing binary file. Check inputs and try again.")
             else:
@@ -934,23 +934,23 @@ def modify_exfile(inputdata=None,qlist=None,exfilename=None,outfile=None,globalt
         extpath = Path(exname+'t')
         if extpath.is_file():
             extfile = opath.parent / (str(opath.stem) + '.ext')
-            shutil.copy2(str(extpath.absolute()),str(extfile.absolute()))
+            shutil.copy2(str(extpath.absolute()), str(extfile.absolute()))
 
     return status
 
 
-def repackage_data(data,quantities):
+def repackage_data(data, quantities):
     """
     Use this function to keep only the specified quantities, reducing the amount of
     memory required to store the JETTO output data.
     """
     odata = None
     qlist = []
-    if isinstance(data,(dict,collections.OrderedDict)):
+    if isinstance(data, (dict, collections.OrderedDict)):
         odata = copy.deepcopy(data)
-    if isinstance(quantities,str):
+    if isinstance(quantities, str):
         qlist = quantities.split(',')
-    elif isinstance(quantities,(list,tuple)):
+    elif isinstance(quantities, (list, tuple)):
         qlist = list(quantities)
 
     if odata is not None and qlist:
@@ -969,9 +969,9 @@ def repackage_data(data,quantities):
     return odata
 
 
-def generate_entry_info(fieldname):
+def generate_entry_info(fieldname, target='jsp'):
     """ Metadata lookup table for a limited set of common ex-file fields. Can be expanded as necessary. """
-    lookup = {
+    lookup_jsp = {
         'RA': (None, 'Minor radius, normalised', 'XVEC1', '1.0', 1.0),
         'XRHO': (None, 'Normalised toroidal flux', 'XVEC1', '1.0', 1.0),
         'PSI': (None, 'Normalised poloidal flux', 'XVEC1', '1.0', 1.0),
@@ -1010,9 +1010,14 @@ def generate_entry_info(fieldname):
         'JZEC': ('A m-2', 'ECRH Driven Curr.Dens', 'XVEC1', '1.0E7', 10000000.0),
         'QEBE': ('W m-3', 'Power Density Electrons', 'XVEC1', '0.1', 0.1),
         'QEBI': ('W m-3', 'Power Density Ions', 'XVEC1', '0.1', 0.1),
-        'JZEB': ('A m-2', 'EBW Driven Curr.Dens', 'XVEC1', '1.0E7', 10000000.0),
+        'JZEB': ('A m-2', 'EBW Driven Curr.Dens', 'XVEC1', '1.0E7', 10000000.0)
+    }
+    lookup_jst = {
         'CUR': ('A', 'Plasma Current', 'TVEC1', '1.0', 1.0)
     }
+    lookup = lookup_jsp
+    if target == 'jst':
+        lookup = lookup_jst
     entry = None
     if fieldname in lookup:
         entry = {'UNITS': None, 'DESC': '', 'SCSTR': '', 'XBASE': '', 'UID': '', 'DDA': '', 'DTYPE': '', 'SEQ': '0', 'SCALE': 1.0, 'LABEL': '', 'FORM': 'float', 'SECNUM': 5}
