@@ -2,6 +2,7 @@
 
 import os
 import re
+import logging
 import subprocess
 import shutil
 import collections
@@ -11,13 +12,22 @@ import tarfile
 import json
 import glob
 import numpy as np
+from pathlib import Path
 from typing import Dict, List, Tuple
 from operator import mul
 from functools import reduce
 
+logger = logging.getLogger('jetto_tools.job')
+logger.setLevel(logging.INFO)
+
 import prominence
 from prominence.exceptions import ProminenceError
 
+try:
+    import docker
+except ImportError:
+    logger.warning("Python module 'docker' not found. function JobManager.submit_job_to_docker needs it")
+
 import jetto_tools.config
 import jetto_tools._utils as _utils
 
@@ -128,6 +138,45 @@ class JobManager:
 
         return id
 
+    def submit_job_to_docker(self, config: jetto_tools.config.RunConfig, 
+                             rundir: Path, 
+                             image: str = "jintrac-imas", 
+                             extra_volumes: dict = {}) :
+        """Submit a JETTO run to docker
+
+        Tries to use docker to run the job.
+
+        :param config: Configuration for the run
+        :type config: jetto_tools.config.RunConfig
+        :param rundir: Relative path to the run directory, with respect to the ``$RUNS_HOME/jetto/runs`` directory
+        :type rundir: str
+        :param image: tag for docker to use to run the job
+        :type image: str
+        :param extra_volumes: extra volumes to mount on the container
+        :type extra_volumes: dict
+        :return: Docker container
+        :rtype: docker.models.containers.Container
+        :raise: JobManagerError if any aspect of submitting the job fails (including Docker failures)
+        """
+        runpath = Path( os.path.join(JobManager._get_run_root(), rundir))
+        try:
+            client = docker.from_env()
+            container = client.containers.run(image, 
+                                              command=f"rjettov -S -I -p -xmpi -x64 -n2 prom build docker",
+                                              volumes={rundir:{'bind': "/jetto/runs/prom", 'mode':'rw'}, 
+                                                       **extra_volumes},
+                                              working_dir="/jetto/runs/prom",
+                                              detach = True,
+                                              auto_remove = True
+                                              )
+        except Error as exc:
+            raise JobManagerError("error in docker") from exc
+
+        with open(runpath/'docker.name', 'w') as f:
+            f.write(f'Job submitted in container with name {container.name}\n')
+
+        return container
+
     @classmethod
     def _find_jetto_source_dir(cls, config: jetto_tools.config.RunConfig) -> str:
         """Find the JETTO source distribution to use
@@ -503,7 +552,7 @@ class JobManager:
         return id
 
     @classmethod
-    def _prom_name(cls, rundir: str) -> str:
+    def _prom_name(cls, rundir ) -> str:
         """Generate a PROMINENCE job/workflow name
 
         Generates the name by replacing directory separators (forward slashes) with
@@ -514,7 +563,7 @@ class JobManager:
         :return: Name
         :rtype: str
         """
-        return rundir.replace('/', '-')
+        return str(rundir).replace('/', '-')
 
     @classmethod
     def _prom_job_description(cls, config: jetto_tools.config.RunConfig, rundir: str, runpath: str,
