@@ -519,6 +519,10 @@ def read_jetto_neoclassical_data(rundir, numions=1, numimps=0):
                 temprminout = np.abs(temprout - np.hstack((np.atleast_2d(tempdata["RI"][:,0]).T,tempdata["RI"]))) / 2.0
                 ndim0 = temprout.shape[0]
 
+                ncdata["afs"] = np.hstack((np.atleast_2d(tempdata["SURF"][:,0]).T,tempdata["SURF"]))
+                ncdata["acs"] = np.hstack((np.atleast_2d(tempdata["AREA"][:,0]).T,tempdata["AREA"]))
+                ncdata["vfs"] = np.hstack((np.atleast_2d(tempdata["VOL"][:,0]).T,tempdata["VOL"]))
+
                 outn = np.hstack((np.atleast_2d(tempdata["NE"][:,0]).T,tempdata["NE"]))
                 outdn = np.hstack((np.zeros((ndim0,1)),np.diff(outn,axis=1) / np.diff(temprminout,axis=1)))
                 outt = np.hstack((np.atleast_2d(tempdata["TE"][:,0]).T,tempdata["TE"]))
