@@ -9,9 +9,19 @@ from dataclasses import dataclass
 from pathlib import Path
 from ast import literal_eval
 
-from idlelib.editor import EditorWindow
-# This import triggers module 'tkinter' has no attribute 'filedialog'
-from idlelib.pyshell import PyShellFileList
+# Set up fancy logging already here
+logger = logging.getLogger(__name__)
+logger.setLevel(logging.INFO)
+
+try:
+    from idlelib.editor import EditorWindow
+    # This import triggers module 'tkinter' has no attribute 'filedialog'
+    from idlelib.pyshell import PyShellFileList
+except ModuleNotFoundError:
+    logger.error("Could not find idlelib build-in! This might indicate a broken"
+                 " Python install. Try seaching for IDLE in your package"
+                 " manager, e.g. `apt-get install idle` on Debian")
+    raise
 from cycler import cycler
 
 import numpy as np
@@ -24,10 +34,6 @@ from jetto_tools.tkinter_helpers import (
     _tkStringVar, SearchableComboBox, _tkDoubleVar, next_path
 )
 
-# Set up fancy logging already here
-logger = logging.getLogger(__name__)
-logger.setLevel(logging.INFO)
-
 try:
     import matplotlib as mpl
     import matplotlib.style.core  # This loads the default library paths
