@@ -8,7 +8,9 @@ import stat
 import re
 import tarfile
 import filecmp
+from pathlib import Path
 import random
+import docker
 import prominence
 from prominence.exceptions import ConnectionError, AuthenticationError, FileUploadError, WorkflowCreationError
 
@@ -88,6 +90,10 @@ def rundir(run_root):
 
     return 'runtestdata'
 
+@pytest.fixture()
+def rundir_path(rundir):
+    return Path(rundir)
+
 
 @pytest.fixture()
 def tar_extract_dir(tmpdir):
@@ -1345,6 +1351,55 @@ class TestSubmitScanToProminence:
 
         assert workflow_name == job_name
 
+@pytest.fixture()
+def mock_docker_client():
+    return mock.Mock(spec=docker.client.DockerClient)
+
+
+@pytest.fixture()
+def mock_docker(mock_docker_client):
+    with mock.patch('docker.from_env',
+                    autospec=docker.from_env) as _fixture:
+        _fixture.return_value = mock_docker_client
+        yield _fixture
+
+class TestSubmitSingleRunToDocker:
+    """Test that we can submit a JETTO job to a local Docker system"""
+    @pytest.fixture()
+    def export(self):
+        """Create three job files in the export directory"""
+        def _fixture(path):
+            for i in range(3):
+                with open(os.path.join(path, f'file{i}.txt'), 'w') as f:
+                    pass
+
+        return _fixture
+
+    def compare_dirs(self, original, tarball):
+        result = True
+        cmp = filecmp.dircmp(original, tarball)
+
+        if cmp.common == cmp.right_list:
+            for file in cmp.common:
+                first_file = os.path.join(original, file)
+                second_file = os.path.join(tarball, file)
+                if not filecmp.cmp(first_file, second_file, shallow=False):
+                    result = False
+        else:
+            result = False
+        return result
+
+    def test_docker_client_created(self, mock_docker, mock_docker_client, manager, mock_config, jintrac_env,
+                                         rundir, rundir_path, run_root):
+        manager.submit_job_to_docker(mock_config, rundir_path)
+
+        mock_docker.assert_called_once()
+
+    def test_docker_container_run_called(self, mock_docker, mock_docker_client, manager, mock_config, jintrac_env,
+                                      rundir, rundir_path, run_root):
+        manager.submit_job_to_docker(mock_config, rundir_path)
+
+        mock_docker_client.containers.run.assert_called_once()
 
 class TestJob:
     @pytest.fixture
